[][src]Struct rustfm::user::recent_tracks::RecentTracks

pub struct RecentTracks {
    pub attrs: Attributes,
    pub tracks: Vec<Track>,
}

The main recent tracks structure.

This is splitted off into two areas: One, the attributes (used for displaying various user-associated attributes), and two, the recent tracks the user has played.

For details on the attributes available, refer to Attributes. For details on the track information available, refer to Track.

Fields

attrs: Attributes

Various user attributes.

tracks: Vec<Track>

A Vec containiing recent Tracks.

Methods

impl RecentTracks[src]

pub fn build<'a>(
    client: &'a mut Client,
    user: &str
) -> RequestBuilder<'a, RecentTracks>
[src]