[−][src]Struct rustfm::user::recent_tracks::TrackAttributes
Fields
now_playing: StringWhether or not the user's first available track is the one the user is currently playing. This is technically "nowplaying" in the Last.fm API, however it was renamed to cohere to Rust's naming conventions.